==> cms-db_v0.7.11.tar.gz: admin/locales/it/common.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['common'] = array();

# Start: Buttons
$locale['common']['button_ok'] = 'OK';
$locale['common']['button_save'] = 'Salva';
$locale['common']['button_cancel'] = 'Cancella';
$locale['common']['button_yes'] = 'Sì';
$locale['common']['button_no'] = 'No';
$locale['common']['button_send'] = 'Invia';
$locale['common']['button_reset'] = 'Cancella';
# End: Buttons

# Start: Categories
$locale['common']['desc_pages'] = 'Amministrazione pagine';
$locale['common']['desc_files'] = 'Amministrazione file';
$locale['common']['desc_includes'] = 'Include';
$locale['common']['desc_settings'] = 'Impostazioni';
$locale['common']['desc_template'] = 'Template/design';
$locale['common']['desc_space'] = 'Spazio disco';
$locale['common']['desc_fileperms'] = 'Permessi file';
$locale['common']['desc_backup'] = 'Backup';
$locale['common']['desc_guestbook'] = 'Libro degli ospiti';
$locale['common']['desc_blog'] = 'Blog';
$locale['common']['desc_stats'] = 'Statistiche';
$locale['common']['desc_recyclebin'] = 'Cestino';
# End: Categories

# Start: Settings
$locale['common']['link_usersettings'] = 'Utenti';
$locale['common']['link_commonsettings'] = 'Impostazioni globali';
$locale['common']['link_urlsettings'] = 'URL';
$locale['common']['link_ftpsettings'] = 'FTP';
$locale['common']['link_adminsettings'] = 'Aspetto';
$locale['common']['link_localesettings'] = 'Lingua';
$locale['common']['desc_settings-saved'] = 'Le impostazioni sono state salvate.';
# End: Settings

# Start: Errors
$locale['common']['title_error'] = 'Errore';
$locale['common']['desc_error-open-file'] = 'Non è stato possibile aprire il file <i>%s</i>.';
$locale['common']['desc_error-write-file'] = 'Non è stato possibile scrivere nel file <i>%s</i>.';
$locale['common']['desc_error-fileperms'] = 'Non hai il permesso necessario per scrivere sul file <i>%s</i>.';
$locale['common']['desc_error-move-file'] = 'Non è stato possibile muovere il file.';
$locale['common']['desc_error-input'] = 'Hai lasciato vuoto uno o più campi obbligatori!';
$locale['common']['link_back'] = 'Indietro';
# End: Errors

# Start: WYMeditor
$locale['common']['wymeditor_align_left'] = 'Giustificato a sinistra';
$locale['common']['wymeditor_align_right'] = 'Giustificato a destra';
$locale['common']['wymeditor_align_clear'] = 'Concludi la giustificazione';
$locale['common']['wymeditor_attributes'] = 'Proprietà';
$locale['common']['wymeditor_new_window'] = 'Nuova finestra';
$locale['common']['wymeditor_new_window_title'] = 'Apri il link in una nuova finestra';
$locale['common']['wymeditor_anchor'] = 'ID dell\'àncora';
$locale['common']['wymeditor_anchor_title'] = 'Aggiungi un\'àncora (attributo id)';
$locale['common']['wymeditor_value'] = 'Valore:';
$locale['common']['wymeditor_wrong_element'] = 'Questa proprietà non può essere assegnata all\'elemento selezionato.';
$locale['common']['wymeditor_error_external'] = 'Questa funzione è normalmente disattivata.';
$locale['common']['wymeditor_error_external_why'] = 'Perché?';
$locale['common']['wymeditor_error_external_more1'] = 'L\'attributo per aprire un link in una nuova finestra non è permesso nel formato XHTML 1.0 Strict.';
$locale['common']['wymeditor_error_external_more2'] = 'Per specificare che la pagina sia aperta in una nuova finestra occorre quindi utilizzare un trucco. Il trucco richiede Javascript a potrebbe non funzionare per gli utenti che bloccano l\'apertura di nuove finestre (popup).';
$locale['common']['wymeditor_error_external_more3'] = 'Utilizza questa funzione con cautela!';
# End: WYMeditor

# Start: Editor
$locale['common']['desc_javascript'] = 'Per poter inserire indirizzi o utilizzare l\'editor grafico è necessario attivare Javascript.';
$locale['common']['desc_insert-page'] = 'Pagine';
$locale['common']['desc_insert-file'] = 'File';
# End: Editor

# Start: Password
$locale['common']['label_oldpw'] = 'Vecchia password:';
$locale['common']['label_newpw'] = 'Nuova password:';
$locale['common']['desc_repeat'] = 'Ripeti la nuova password:';
$locale['common']['desc_error-invalid-data'] = 'I dati inseriti non sono validi.';
# End: Password

# Start: Dates
$locale['common']['date_day1'] = 'Domenica';
$locale['common']['date_day2'] = 'Lunedì';
$locale['common']['date_day3'] = 'Martedì';
$locale['common']['date_day4'] = 'Mercoledì';
$locale['common']['date_day5'] = 'Giovedì';
$locale['common']['date_day6'] = 'Venerdì';
$locale['common']['date_day7'] = 'Sabato';
$locale['common']['date_month1'] = 'Gennaio';
$locale['common']['date_month2'] = 'Febbraio';
$locale['common']['date_month3'] = 'Marzo';
$locale['common']['date_month4'] = 'Aprile';
$locale['common']['date_month5'] = 'Maggio';
$locale['common']['date_month6'] = 'Giugno';
$locale['common']['date_month7'] = 'Luglio';
$locale['common']['date_month8'] = 'Agosto';
$locale['common']['date_month9'] = 'Settembre';
$locale['common']['date_month10'] = 'Ottobre';
$locale['common']['date_month11'] = 'Novembre';
$locale['common']['date_month12'] = 'Dicembre';
$locale['common']['date_dateformat'] = '+day, +d +month +y';
$locale['common']['date_timeformat'] = '+h,+m';
# End: Dates

$locale['common']['label_username'] = 'Nome utente';
$locale['common']['label_password'] = 'Password';

$locale['common']['link_next'] = 'Avanti';
$locale['common']['link_edit'] = 'modifica';
$locale['common']['link_rename'] = 'cambia nome';
$locale['common']['link_delete'] = 'cancella';
$locale['common']['desc_action'] = 'Azione';

$locale['common']['title_editpage'] = 'Modifica pagina';

$locale['common']['button_create'] = 'Crea';

$locale['common']['link_close'] = 'Chiudi';
?>

==> cms-db_v0.8.1.tar.gz: admin/locales/it/common.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['common'] = array();

# Start: Buttons
$locale['common']['button_ok'] = 'OK';
$locale['common']['button_save'] = 'Salva';
$locale['common']['button_cancel'] = 'Cancella';
$locale['common']['button_yes'] = 'Sì';
$locale['common']['button_no'] = 'No';
$locale['common']['button_send'] = 'Invia';
$locale['common']['button_reset'] = 'Cancella';
# End: Buttons

# Start: Categories
$locale['common']['desc_pages'] = 'Amministrazione pagine';
$locale['common']['desc_files'] = 'Amministrazione file';
$locale['common']['desc_includes'] = 'Include';
$locale['common']['desc_settings'] = 'Impostazioni';
$locale['common']['desc_template'] = 'Template/design';
$locale['common']['desc_space'] = 'Spazio disco';
$locale['common']['desc_fileperms'] = 'Permessi file';
$locale['common']['desc_backup'] = 'Backup';
$locale['common']['desc_guestbook'] = 'Libro degli ospiti';
$locale['common']['desc_blog'] = 'Blog';
$locale['common']['desc_stats'] = 'Statistiche';
$locale['common']['desc_recyclebin'] = 'Cestino';
# End: Categories

# Start: Settings
$locale['common']['link_usersettings'] = 'Utenti';
$locale['common']['link_commonsettings'] = 'Impostazioni globali';
$locale['common']['link_urlsettings'] = 'URL';
$locale['common']['link_ftpsettings'] = 'FTP';
$locale['common']['link_adminsettings'] = 'Aspetto';
$locale['common']['link_localesettings'] = 'Lingua';
$locale['common']['desc_settings-saved'] = 'Le impostazioni sono state salvate.';
# End: Settings

# Start: Errors
$locale['common']['title_error'] = 'Errore';
$locale['common']['desc_error-open-file'] = 'Non è stato possibile aprire il file <i>%s</i>.';
$locale['common']['desc_error-write-file'] = 'Non è stato possibile scrivere nel file <i>%s</i>.';
$locale['common']['desc_error-fileperms'] = 'Non hai il permesso necessario per scrivere sul file <i>%s</i>.';
$locale['common']['desc_error-move-file'] = 'Non è stato possibile muovere il file.';
$locale['common']['desc_error-input'] = 'Hai lasciato vuoto uno o più campi obbligatori!';
$locale['common']['link_back'] = 'Indietro';
# End: Errors

# Start: WYMeditor
$locale['common']['wymeditor_align_left'] = 'Giustificato a sinistra';
$locale['common']['wymeditor_align_right'] = 'Giustificato a destra';
$locale['common']['wymeditor_align_clear'] = 'Concludi la giustificazione';
$locale['common']['wymeditor_attributes'] = 'Proprietà';
$locale['common']['wymeditor_new_window'] = 'Nuova finestra';
$locale['common']['wymeditor_new_window_title'] = 'Apri il link in una nuova finestra';
$locale['common']['wymeditor_anchor'] = 'ID dell\'àncora';
$locale['common']['wymeditor_anchor_title'] = 'Aggiungi un\'àncora (attributo id)';
$locale['common']['wymeditor_value'] = 'Valore:';
$locale['common']['wymeditor_wrong_element'] = 'Questa proprietà non può essere assegnata all\'elemento selezionato.';
$locale['common']['wymeditor_error_external'] = 'Questa funzione è normalmente disattivata.';
$locale['common']['wymeditor_error_external_why'] = 'Perché?';
$locale['common']['wymeditor_error_external_more1'] = 'L\'attributo per aprire un link in una nuova finestra non è permesso nel formato XHTML 1.0 Strict.';
$locale['common']['wymeditor_error_external_more2'] = 'Per specificare che la pagina sia aperta in una nuova finestra occorre quindi utilizzare un trucco. Il trucco richiede Javascript e potrebbe non funzionare per gli utenti che bloccano l\'apertura di nuove finestre (popup).';
$locale['common']['wymeditor_error_external_more3'] = 'Utilizza questa funzione con cautela!';
# End: WYMeditor

# Start: Editor
$locale['common']['desc_javascript'] = 'Per poter inserire indirizzi o utilizzare l\'editor grafico è necessario attivare Javascript.';
$locale['common']['desc_insert-page'] = 'Pagine';
$locale['common']['desc_insert-file'] = 'File';
# End: Editor

# Start: Autosave
$locale['common']['desc_autosave-version'] = 'Questa è una bozza della pagina salvata precedentemente.';
$locale['common']['desc_autosave-blog'] = 'Questa è una bozza dell\'articolo blog salvata precedentemente.';
$locale['common']['link_discard-changes'] = 'Non applicare i cambiamenti';
$locale['common']['link_delete-draft'] = 'Cancella bozza';
$locale['common']['button_publish'] = 'Pubblica';
$locale['common']['button_savedraft'] = 'Salva bozza';
$locale['common']['desc_autosave-saved'] = 'Salvataggio effettuato.';
$locale['common']['desc_autosave-saving'] = 'Salvataggio in corso...';
$locale['common']['desc_autosave-skipped'] = 'Salvataggio saltato.';
$locale['common']['desc_autosave-next'] = 'Prossimo salvataggio tra %s secondi...';
$locale['common']['desc_draft'] = 'Bozza';
# End: Autosave

# Start: Password
$locale['common']['label_oldpw'] = 'Vecchia password:';
$locale['common']['label_newpw'] = 'Nuova password:';
$locale['common']['desc_repeat'] = 'Ripeti la nuova password:';
$locale['common']['desc_error-invalid-data'] = 'I dati inseriti non sono validi.';
# End: Password

# Start: Dates
$locale['common']['date_day1'] = 'Domenica';
$locale['common']['date_day2'] = 'Lunedì';
$locale['common']['date_day3'] = 'Martedì';
$locale['common']['date_day4'] = 'Mercoledì';
$locale['common']['date_day5'] = 'Giovedì';
$locale['common']['date_day6'] = 'Venerdì';
$locale['common']['date_day7'] = 'Sabato';
$locale['common']['date_month1'] = 'Gennaio';
$locale['common']['date_month2'] = 'Febbraio';
$locale['common']['date_month3'] = 'Marzo';
$locale['common']['date_month4'] = 'Aprile';
$locale['common']['date_month5'] = 'Maggio';
$locale['common']['date_month6'] = 'Giugno';
$locale['common']['date_month7'] = 'Luglio';
$locale['common']['date_month8'] = 'Agosto';
$locale['common']['date_month9'] = 'Settembre';
$locale['common']['date_month10'] = 'Ottobre';
$locale['common']['date_month11'] = 'Novembre';
$locale['common']['date_month12'] = 'Dicembre';
$locale['common']['date_dateformat'] = '+day, +d +month +y';
$locale['common']['date_timeformat'] = '+h,+m';
# End: Dates

# Start: Insert
$locale['common']['desc_cantinsert'] = 'Non è stato possibile inserire l\'indirizzo URL. Prova a copiare l\'URL dal link nella lista o dal menù del sito.';
# End: Insert

# Start: CSRF Protection Error
$locale['common']['title_csrfprotection'] = 'Codice di verifica non valido o mancante';
$locale['common']['desc_csrfprotection'] = 'Il codice di verifica per la pagina richiesta non è stato trasferito correttamente. Questo può essere dovuto ad un attacco CSRF. Un\'altra ragione potrebbe essere un errore di programmazione.';
# End: CSRF Protection Error

$locale['common']['label_username'] = 'Nome utente';
$locale['common']['label_password'] = 'Password';

$locale['common']['link_next'] = 'Avanti';
$locale['common']['link_edit'] = 'modifica';
$locale['common']['link_rename'] = 'cambia nome';
$locale['common']['link_delete'] = 'cancella';
$locale['common']['desc_action'] = 'Azione';

$locale['common']['title_editpage'] = 'Modifica pagina';

$locale['common']['button_create'] = 'Crea';

$locale['common']['link_close'] = 'Chiudi';
?>
